# MetaCast


A package for broad**CAST**ing epidemiological and ecological models over **META**-populations.

## Installation


### Requirements

Python 3.10 and pip.
Package requirements:
* numpy >= 1.26.3
* pandas >= 2.1.4
* scipy >= 1.11.4
* pingouin >= 0.5.4
* tqdm >= 4.66.1
* dask >= 2024.2.1
* distributed >= 2024.2.1

For running [demonstration jupyter notebooks](https://github.com/m-d-grunnill/MetaCast/tree/main/demonstrations)
* bokeh >= 3.3.4
* seaborn >= 0.13.2
* jupyter >= 1.0.0

### Installing via pip
**Note** this should also install required packages.
```
pip install metacast
```

## Usage
See jupyter notebooks in demonstration directory of homepage:
[https://github.com/m-d-grunnill/MetaCast/tree/main/demonstrations](https://github.com/m-d-grunnill/MetaCast/tree/main/demonstrations)

## Documentation
[https://metacast.readthedocs.io/en/latest/index.html](https://metacast.readthedocs.io/en/latest/index.html)
